import { getAirLinesListApi, getAircraftNumbersApi, getAircraftTerminalsApi, getBasicParamsListApi, getFlightNumApi } from 'mocp/api/base'
import { defineStore } from 'pinia'

const useBaseStore = defineStore('base', {
    state: () => {
        return {
            selectList: {
                deviceNumList: [], //机号
                terminalList: [], //航站下拉数据
                airlineCodeList: [], //航司下拉数据
                flightNumList: [] //航班号下拉数据
            },
            allBasicParams: {} //系统基础参数
        }
    },
    getters: {
        //格式化航站数据
        getTerminalObject(state) {
            return state.selectList.terminalList?.reduce((q, w) => {
                if (!q[w.terminalCode]) {
                    q[w.terminalCode] = []
                }
                q[w.terminalCode] = w.terminalCity + '-' + w.terminalName + '-' + w.terminalCode
                return q
            }, {})
        },
        getTerminalSelect(state) {
            return state.selectList.terminalList?.map((z) => ({
                value: z.terminalCode,
                label: z.terminalCity + '-' + z.terminalName + '-' + z.terminalCode
            }))
        },
        //格式化航司数据
        getAirlineSelect(state) {
            return state.selectList.airlineCodeList.map((z) => ({
                value: z.zOP3,
                zOP2: z.value,
                label: z.zOP3 + z.shortName
            }))
        }
    },
    actions: {
        async initSysData() {
            uni.showLoading({
                title: '正在加载系统所有基本参数中，请稍后！',
                mask: true
            })
            try {
                await Promise.all(
                    this.getAircraftNumbers(),
                    this.getBasicParamsList(),
                    this.getAircraftTerminals(),
                    this.getAirLinesList(),
                    this.getFlightNum()
                )
                uni.hideLoading()
            } catch (error) {
                uni.hideLoading()
            }
        },
        async getAircraftNumbers() {
            const res = await getAircraftNumbersApi({})
            if (res.code == 200) {
                this.selectList.deviceNumList = res.data
            }
        },
        async getAircraftTerminals() {
            const res = await getAircraftTerminalsApi({})
            if (res.code == 200) {
                this.selectList.terminalList = res.data
            }
        },
        async getAirLinesList() {
            const res = await getAirLinesListApi({})
            if (res.code == 200) {
                this.selectList.airlineCodeList = res.data
                    .filter((a) => a.sortId !== '0')
                    .sort((q, w) => Number(q.sortId) - Number(w.sortId))
                    .map((z) => ({
                        value: z.zOP2,
                        label: z.zOP2,
                        name: z.zCNAME20,
                        zOP3: z.zOP3,
                        shortName: z.reduceName,
                        zCFNAME: z.zCFNAME
                    }))
            }
        },
        async getFlightNum() {
            const res = await getFlightNumApi({})
            if (res.code == 200) {
                this.selectList.flightNumList = res.data
            }
        },
        async getBasicParamsList() {
            const res = await getBasicParamsListApi({})
            if (res.code == 200) {
                this.allBasicParams = res.data.reduce((q, w) => {
                    if (!q[w.paramType]) {
                        q[w.paramType] = []
                    }
                    q[w.paramType].push(w)
                    return q
                }, {})
            }
        },
        getParamsByType(paramType) {
            return this.allBasicParams[paramType]
                ?.filter((item) => item.isDel == 0)
                ?.map((item) => {
                    return { label: item.paramName, value: item.paramCode }
                })
        },
        getParamNameByValue(paramType, paramName) {
            return this.getParamsByType(paramType).find((item) => item.value == paramName)?.label || ''
        }
    },
    // 配置持久化
    persist: {
        // 调整为兼容多端的API
        storage: {
            setItem(key, value) {
                uni.setStorageSync(key, value)
            },
            getItem(key) {
                return uni.getStorageSync(key)
            }
        }
    }
})
export default useBaseStore
